@@ -27,7 +27,6 @@
 #include "extconf.h"
 #include "stream.h"
 
-#if HAVE_TYPE_VIRSTORAGEVOLPTR
 /* this has to be here (as opposed to below with the rest of the volume
  * stuff) because libvirt_storage_vol_get_pool() relies on it
  */
@@ -35,9 +34,7 @@ static virStorageVolPtr vol_get(VALUE v)
 {
     ruby_libvirt_get_struct(StorageVol, v);
 }
-#endif
 
-#if HAVE_TYPE_VIRSTORAGEPOOLPTR
 static VALUE c_storage_pool;
 static VALUE c_storage_pool_info;
 
@@ -64,7 +61,7 @@ VALUE pool_new(virStoragePoolPtr p, VALUE conn)
  * call-seq:
  *   vol.pool -> Libvirt::StoragePool
  *
- * Call virStoragePoolLookupByVolume[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolLookupByVolume]
+ * Call virStoragePoolLookupByVolume[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolLookupByVolume]
  * to retrieve the storage pool for this volume.
  */
 static VALUE libvirt_storage_vol_pool(VALUE v)
@@ -83,7 +80,7 @@ static VALUE libvirt_storage_vol_pool(VALUE v)
  * call-seq:
  *   pool.build(flags=0) -> nil
  *
- * Call virStoragePoolBuild[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolBuild]
+ * Call virStoragePoolBuild[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolBuild]
  * to build this storage pool.
  */
 static VALUE libvirt_storage_pool_build(int argc, VALUE *argv, VALUE p)
@@ -102,7 +99,7 @@ static VALUE libvirt_storage_pool_build(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.undefine -> nil
  *
- * Call virStoragePoolUndefine[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolUndefine]
+ * Call virStoragePoolUndefine[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolUndefine]
  * to undefine this storage pool.
  */
 static VALUE libvirt_storage_pool_undefine(VALUE p)
@@ -116,7 +113,7 @@ static VALUE libvirt_storage_pool_undefine(VALUE p)
  * call-seq:
  *   pool.create(flags=0) -> nil
  *
- * Call virStoragePoolCreate[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolCreate]
+ * Call virStoragePoolCreate[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolCreate]
  * to start this storage pool.
  */
 static VALUE libvirt_storage_pool_create(int argc, VALUE *argv, VALUE p)
@@ -135,7 +132,7 @@ static VALUE libvirt_storage_pool_create(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.destroy -> nil
  *
- * Call virStoragePoolDestroy[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDestroy]
+ * Call virStoragePoolDestroy[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDestroy]
  * to shutdown this storage pool.
  */
 static VALUE libvirt_storage_pool_destroy(VALUE p)
@@ -149,7 +146,7 @@ static VALUE libvirt_storage_pool_destroy(VALUE p)
  * call-seq:
  *   pool.delete(flags=0) -> nil
  *
- * Call virStoragePoolDelete[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDelete]
+ * Call virStoragePoolDelete[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolDelete]
  * to delete the data corresponding to this data pool.  This is a destructive
  * operation.
  */
@@ -169,7 +166,7 @@ static VALUE libvirt_storage_pool_delete(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.refresh(flags=0) -> nil
  *
- * Call virStoragePoolRefresh[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolRefresh]
+ * Call virStoragePoolRefresh[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolRefresh]
  * to refresh the list of volumes in this storage pool.
  */
 static VALUE libvirt_storage_pool_refresh(int argc, VALUE *argv, VALUE p)
@@ -188,7 +185,7 @@ static VALUE libvirt_storage_pool_refresh(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.name -> String
  *
- * Call virStoragePoolGetName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetName]
+ * Call virStoragePoolGetName[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetName]
  * to retrieve the name of this storage pool.
  */
 static VALUE libvirt_storage_pool_name(VALUE p)
@@ -202,7 +199,7 @@ static VALUE libvirt_storage_pool_name(VALUE p)
  * call-seq:
  *   pool.uuid -> String
  *
- * Call virStoragePoolGetUUIDString[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetUUIDString]
+ * Call virStoragePoolGetUUIDString[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetUUIDString]
  * to retrieve the UUID of this storage pool.
  */
 static VALUE libvirt_storage_pool_uuid(VALUE p)
@@ -215,7 +212,7 @@ static VALUE libvirt_storage_pool_uuid(VALUE p)
  * call-seq:
  *   pool.info -> Libvirt::StoragePoolInfo
  *
- * Call virStoragePoolGetInfo[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetInfo]
+ * Call virStoragePoolGetInfo[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetInfo]
  * to retrieve information about this storage pool.
  */
 static VALUE libvirt_storage_pool_info(VALUE p)
@@ -242,7 +239,7 @@ static VALUE libvirt_storage_pool_info(VALUE p)
  * call-seq:
  *   pool.xml_desc(flags=0) -> String
  *
- * Call virStoragePoolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetXMLDesc]
+ * Call virStoragePoolGetXMLDesc[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetXMLDesc]
  * to retrieve the XML for this storage pool.
  */
 static VALUE libvirt_storage_pool_xml_desc(int argc, VALUE *argv, VALUE p)
@@ -261,7 +258,7 @@ static VALUE libvirt_storage_pool_xml_desc(int argc, VALUE *argv, VALUE p)
  * call-seq:
  *   pool.autostart? -> [true|false]
  *
- * Call virStoragePoolGetAutostart[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetAutostart]
+ * Call virStoragePoolGetAutostart[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolGetAutostart]
  * to determine whether this storage pool will autostart when libvirtd starts.
  */
 static VALUE libvirt_storage_pool_autostart(VALUE p)
@@ -280,7 +277,7 @@ static VALUE libvirt_storage_pool_autostart(VALUE p)
  * call-seq:
  *   pool.autostart = [true|false]
  *
- * Call virStoragePoolSetAutostart[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolSetAutostart]
+ * Call virStoragePoolSetAutostart[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolSetAutostart]
  * to make this storage pool start when libvirtd starts.
  */
 static VALUE libvirt_storage_pool_autostart_equal(VALUE p, VALUE autostart)
@@ -299,7 +296,7 @@ static VALUE libvirt_storage_pool_autostart_equal(VALUE p, VALUE autostart)
  * call-seq:
  *   pool.num_of_volumes -> Fixnum
  *
- * Call virStoragePoolNumOfVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolNumOfVolumes]
+ * Call virStoragePoolNumOfVolumes[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolNumOfVolumes]
  * to retrieve the number of volumes in this storage pool.
  */
 static VALUE libvirt_storage_pool_num_of_volumes(VALUE p)
@@ -318,7 +315,7 @@ static VALUE libvirt_storage_pool_num_of_volumes(VALUE p)
  * call-seq:
  *   pool.list_volumes -> list
  *
- * Call virStoragePoolListVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListVolumes]
+ * Call virStoragePoolListVolumes[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListVolumes]
  * to retrieve a list of volume names in this storage pools.
  */
 static VALUE libvirt_storage_pool_list_volumes(VALUE p)
@@ -347,7 +344,7 @@ static VALUE libvirt_storage_pool_list_volumes(VALUE p)
  * call-seq:
  *   pool.free -> nil
  *
- * Call virStoragePoolFree[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolFree]
+ * Call virStoragePoolFree[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolFree]
  * to free this storage pool object.  After this call the storage pool object
  * is no longer valid.
  */
@@ -355,9 +352,7 @@ static VALUE libvirt_storage_pool_free(VALUE p)
 {
     ruby_libvirt_generate_call_free(StoragePool, p);
 }
-#endif
 
-#if HAVE_TYPE_VIRSTORAGEVOLPTR
 /*
  * Libvirt::StorageVol
  */
@@ -378,7 +373,7 @@ static VALUE vol_new(virStorageVolPtr v, VALUE conn)
  * call-seq:
  *   pool.lookup_volume_by_name(name) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByName]
+ * Call virStorageVolLookupByName[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByName]
  * to retrieve a storage volume object by name.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_name(VALUE p, VALUE name)
@@ -397,7 +392,7 @@ static VALUE libvirt_storage_pool_lookup_vol_by_name(VALUE p, VALUE name)
  * call-seq:
  *   pool.lookup_volume_by_key(key) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByKey[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByKey]
+ * Call virStorageVolLookupByKey[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByKey]
  * to retrieve a storage volume object by key.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_key(VALUE p, VALUE key)
@@ -418,7 +413,7 @@ static VALUE libvirt_storage_pool_lookup_vol_by_key(VALUE p, VALUE key)
  * call-seq:
  *   pool.lookup_volume_by_path(path) -> Libvirt::StorageVol
  *
- * Call virStorageVolLookupByPath[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByPath]
+ * Call virStorageVolLookupByPath[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolLookupByPath]
  * to retrieve a storage volume object by path.
  */
 static VALUE libvirt_storage_pool_lookup_vol_by_path(VALUE p, VALUE path)
@@ -435,12 +430,11 @@ static VALUE libvirt_storage_pool_lookup_vol_by_path(VALUE p, VALUE path)
     return vol_new(vol, ruby_libvirt_conn_attr(p));
 }
 
-#if HAVE_VIRSTORAGEPOOLLISTALLVOLUMES
 /*
  * call-seq:
  *   pool.list_all_volumes(flags=0) -> Array
  *
- * Call virStoragePoolListAllVolumes[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListAllVolumes]
+ * Call virStoragePoolListAllVolumes[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolListAllVolumes]
  * to get an array of volume objects for all volumes.
  */
 static VALUE libvirt_storage_pool_list_all_volumes(int argc, VALUE *argv,
@@ -448,16 +442,15 @@ static VALUE libvirt_storage_pool_list_all_volumes(int argc, VALUE *argv,
 {
     ruby_libvirt_generate_call_list_all(virStorageVolPtr, argc, argv,
                                         virStoragePoolListAllVolumes,
-                                        pool_get(p), p, vol_new,
-                                        virStorageVolFree);
+                                        pool_get(p), ruby_libvirt_conn_attr(p),
+                                        vol_new, virStorageVolFree);
 }
-#endif
 
 /*
  * call-seq:
  *   vol.name -> String
  *
- * Call virStorageVolGetName[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetName]
+ * Call virStorageVolGetName[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetName]
  * to retrieve the name of this storage volume.
  */
 static VALUE libvirt_storage_vol_name(VALUE v)
@@ -471,7 +464,7 @@ static VALUE libvirt_storage_vol_name(VALUE v)
  * call-seq:
  *   vol.key -> String
  *
- * Call virStorageVolGetKey[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetKey]
+ * Call virStorageVolGetKey[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetKey]
  * to retrieve the key for this storage volume.
  */
 static VALUE libvirt_storage_vol_key(VALUE v)
@@ -485,7 +478,7 @@ static VALUE libvirt_storage_vol_key(VALUE v)
  * call-seq:
  *   pool.create_volume_xml(xml, flags=0) -> Libvirt::StorageVol
  *
- * Call virStorageVolCreateXML[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXML]
+ * Call virStorageVolCreateXML[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXML]
  * to create a new storage volume from xml.
  */
 static VALUE libvirt_storage_pool_create_volume_xml(int argc, VALUE *argv,
@@ -504,12 +497,11 @@ static VALUE libvirt_storage_pool_create_volume_xml(int argc, VALUE *argv,
     return vol_new(vol, ruby_libvirt_conn_attr(p));
 }
 
-#if HAVE_VIRSTORAGEVOLCREATEXMLFROM
 /*
  * call-seq:
  *   pool.create_volume_xml_from(xml, clonevol, flags=0) -> Libvirt::StorageVol
  *
- * Call virStorageVolCreateXMLFrom[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXMLFrom]
+ * Call virStorageVolCreateXMLFrom[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolCreateXMLFrom]
  * to clone a volume from an existing volume with the properties specified in
  * xml.
  */
@@ -530,14 +522,12 @@ static VALUE libvirt_storage_pool_create_volume_xml_from(int argc, VALUE *argv,
 
     return vol_new(vol, ruby_libvirt_conn_attr(p));
 }
-#endif
 
-#if HAVE_VIRSTORAGEPOOLISACTIVE
 /*
  * call-seq:
  *   pool.active? -> [true|false]
  *
- * Call virStoragePoolIsActive[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsActive]
+ * Call virStoragePoolIsActive[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsActive]
  * to determine if this storage pool is active.
  */
 static VALUE libvirt_storage_pool_active_p(VALUE p)
@@ -546,14 +536,12 @@ static VALUE libvirt_storage_pool_active_p(VALUE p)
                                          ruby_libvirt_connect_get(p),
                                          pool_get(p));
 }
-#endif
 
-#if HAVE_VIRSTORAGEPOOLISPERSISTENT
 /*
  * call-seq:
  *   pool.persistent? -> [true|false]
  *
- * Call virStoragePoolIsPersistent[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsPersistent]
+ * Call virStoragePoolIsPersistent[https://libvirt.org/html/libvirt-libvirt-storage.html#virStoragePoolIsPersistent]
  * to determine if this storage pool is persistent.
  */
 static VALUE libvirt_storage_pool_persistent_p(VALUE p)
@@ -562,13 +550,12 @@ static VALUE libvirt_storage_pool_persistent_p(VALUE p)
                                          ruby_libvirt_connect_get(p),
                                          pool_get(p));
 }
-#endif
 
 /*
  * call-seq:
  *   vol.delete(flags=0) -> nil
  *
- * Call virStorageVolDelete[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDelete]
+ * Call virStorageVolDelete[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDelete]
  * to delete this volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_delete(int argc, VALUE *argv, VALUE v)
@@ -583,12 +570,11 @@ static VALUE libvirt_storage_vol_delete(int argc, VALUE *argv, VALUE v)
                                    ruby_libvirt_value_to_uint(flags));
 }
 
-#if HAVE_VIRSTORAGEVOLWIPE
 /*
  * call-seq:
  *   vol.wipe(flags=0) -> nil
  *
- * Call virStorageVolWipe[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipe]
+ * Call virStorageVolWipe[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipe]
  * to wipe the data from this storage volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_wipe(int argc, VALUE *argv, VALUE v)
@@ -602,13 +588,12 @@ static VALUE libvirt_storage_vol_wipe(int argc, VALUE *argv, VALUE v)
                                    vol_get(v),
                                    ruby_libvirt_value_to_uint(flags));
 }
-#endif
 
 /*
  * call-seq:
  *   vol.info -> Libvirt::StorageVolInfo
  *
- * Call virStorageVolGetInfo[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetInfo]
+ * Call virStorageVolGetInfo[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetInfo]
  * to retrieve information about this storage volume.
  */
 static VALUE libvirt_storage_vol_info(VALUE v)
@@ -633,7 +618,7 @@ static VALUE libvirt_storage_vol_info(VALUE v)
  * call-seq:
  *   vol.xml_desc(flags=0) -> String
  *
- * Call virStorageVolGetXMLDesc[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetXMLDesc]
+ * Call virStorageVolGetXMLDesc[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetXMLDesc]
  * to retrieve the xml for this storage volume.
  */
 static VALUE libvirt_storage_vol_xml_desc(int argc, VALUE *argv, VALUE v)
@@ -652,7 +637,7 @@ static VALUE libvirt_storage_vol_xml_desc(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.path -> String
  *
- * Call virStorageVolGetPath[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetPath]
+ * Call virStorageVolGetPath[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolGetPath]
  * to retrieve the path for this storage volume.
  */
 static VALUE libvirt_storage_vol_path(VALUE v)
@@ -666,7 +651,7 @@ static VALUE libvirt_storage_vol_path(VALUE v)
  * call-seq:
  *   vol.free -> nil
  *
- * Call virStorageVolFree[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolFree]
+ * Call virStorageVolFree[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolFree]
  * to free the storage volume object.  After this call the storage volume object
  * is no longer valid.
  */
@@ -674,14 +659,12 @@ static VALUE libvirt_storage_vol_free(VALUE v)
 {
     ruby_libvirt_generate_call_free(StorageVol, v);
 }
-#endif
 
-#if HAVE_VIRSTORAGEVOLDOWNLOAD
 /*
  * call-seq:
  *   vol.download(stream, offset, length, flags=0) -> nil
  *
- * Call virStorageVolDownload[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDownload]
+ * Call virStorageVolDownload[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolDownload]
  * to download the content of a volume as a stream.
  */
 static VALUE libvirt_storage_vol_download(int argc, VALUE *argv, VALUE v)
@@ -701,7 +684,7 @@ static VALUE libvirt_storage_vol_download(int argc, VALUE *argv, VALUE v)
  * call-seq:
  *   vol.upload(stream, offset, length, flags=0) -> nil
  *
- * Call virStorageVolUpload[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolUpload]
+ * Call virStorageVolUpload[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolUpload]
  * to upload new content to a volume from a stream.
  */
 static VALUE libvirt_storage_vol_upload(int argc, VALUE *argv, VALUE v)
@@ -716,14 +699,12 @@ static VALUE libvirt_storage_vol_upload(int argc, VALUE *argv, VALUE v)
                                    NUM2ULL(offset), NUM2ULL(length),
                                    ruby_libvirt_value_to_uint(flags));
 }
-#endif
 
-#if HAVE_VIRSTORAGEVOLWIPEPATTERN
 /*
  * call-seq:
  *   vol.wipe_pattern(alg, flags=0) -> nil
  *
- * Call virStorageVolWipePattern[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipePattern]
+ * Call virStorageVolWipePattern[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolWipePattern]
  * to wipe the data from this storage volume.  This is a destructive operation.
  */
 static VALUE libvirt_storage_vol_wipe_pattern(int argc, VALUE *argv, VALUE v)
@@ -737,14 +718,12 @@ static VALUE libvirt_storage_vol_wipe_pattern(int argc, VALUE *argv, VALUE v)
                                    vol_get(v), NUM2UINT(alg),
                                    ruby_libvirt_value_to_uint(flags));
 }
-#endif
 
-#if HAVE_VIRSTORAGEVOLRESIZE
 /*
  * call-seq:
  *   vol.resize(capacity, flags=0) -> nil
  *
- * Call virStorageVolResize[http://www.libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolResize]
+ * Call virStorageVolResize[https://libvirt.org/html/libvirt-libvirt-storage.html#virStorageVolResize]
  * to resize the associated storage volume.
  */
 static VALUE libvirt_storage_vol_resize(int argc, VALUE *argv, VALUE v)
@@ -758,14 +737,12 @@ static VALUE libvirt_storage_vol_resize(int argc, VALUE *argv, VALUE v)
                                    vol_get(v), NUM2ULL(capacity),
                                    ruby_libvirt_value_to_uint(flags));
 }
-#endif
 
 void ruby_libvirt_storage_init(void)
 {
     /*
      * Class Libvirt::StoragePool and Libvirt::StoragePoolInfo
      */
-#if HAVE_TYPE_VIRSTORAGEPOOLPTR
     c_storage_pool_info = rb_define_class_under(m_libvirt, "StoragePoolInfo",
                                                 rb_cObject);
     rb_define_attr(c_storage_pool_info, "state", 1, 0);
@@ -787,15 +764,11 @@ void ruby_libvirt_storage_init(void)
                     INT2NUM(VIR_STORAGE_POOL_RUNNING));
     rb_define_const(c_storage_pool, "DEGRADED",
                     INT2NUM(VIR_STORAGE_POOL_DEGRADED));
-#if HAVE_CONST_VIR_STORAGE_POOL_INACCESSIBLE
     rb_define_const(c_storage_pool, "INACCESSIBLE",
                     INT2NUM(VIR_STORAGE_POOL_INACCESSIBLE));
-#endif
 
-#if HAVE_CONST_VIR_STORAGE_XML_INACTIVE
     rb_define_const(c_storage_pool, "XML_INACTIVE",
                     INT2NUM(VIR_STORAGE_XML_INACTIVE));
-#endif
 
     /* virStoragePoolBuildFlags */
     rb_define_const(c_storage_pool, "BUILD_NEW",
@@ -811,31 +784,19 @@ void ruby_libvirt_storage_init(void)
     rb_define_const(c_storage_pool, "DELETE_ZEROED",
                     INT2NUM(VIR_STORAGE_POOL_DELETE_ZEROED));
 
-#if HAVE_CONST_VIR_STORAGE_VOL_CREATE_PREALLOC_METADATA
     rb_define_const(c_storage_pool, "CREATE_PREALLOC_METADATA",
                     INT2NUM(VIR_STORAGE_VOL_CREATE_PREALLOC_METADATA));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_CREATE_REFLINK
     rb_define_const(c_storage_pool, "CREATE_REFLINK",
                     INT2NUM(VIR_STORAGE_VOL_CREATE_REFLINK));
-#endif
 
-#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_NORMAL
     rb_define_const(c_storage_pool, "CREATE_NORMAL",
                     INT2NUM(VIR_STORAGE_POOL_CREATE_NORMAL));
-#endif
-#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD
     rb_define_const(c_storage_pool, "CREATE_WITH_BUILD",
                     INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD));
-#endif
-#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE
     rb_define_const(c_storage_pool, "CREATE_WITH_BUILD_OVERWRITE",
                     INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE));
-#endif
-#if HAVE_CONST_VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE
     rb_define_const(c_storage_pool, "CREATE_WITH_BUILD_NO_OVERWRITE",
                     INT2NUM(VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE));
-#endif
 
     /* Creating/destroying pools */
     rb_define_method(c_storage_pool, "build", libvirt_storage_pool_build, -1);
@@ -875,39 +836,23 @@ void ruby_libvirt_storage_init(void)
     rb_define_method(c_storage_pool, "create_volume_xml",
                      libvirt_storage_pool_create_volume_xml, -1);
     rb_define_alias(c_storage_pool, "create_vol_xml", "create_volume_xml");
-#if HAVE_VIRSTORAGEVOLCREATEXMLFROM
     rb_define_method(c_storage_pool, "create_volume_xml_from",
                      libvirt_storage_pool_create_volume_xml_from, -1);
     rb_define_alias(c_storage_pool, "create_vol_xml_from",
                     "create_volume_xml_from");
-#endif
-#if HAVE_VIRSTORAGEPOOLISACTIVE
     rb_define_method(c_storage_pool, "active?", libvirt_storage_pool_active_p,
                      0);
-#endif
-#if HAVE_VIRSTORAGEPOOLISPERSISTENT
     rb_define_method(c_storage_pool, "persistent?",
                      libvirt_storage_pool_persistent_p, 0);
-#endif
 
-#if HAVE_VIRSTORAGEPOOLLISTALLVOLUMES
     rb_define_method(c_storage_pool, "list_all_volumes",
                      libvirt_storage_pool_list_all_volumes, -1);
-#endif
 
-#if HAVE_CONST_VIR_STORAGE_POOL_BUILD_NO_OVERWRITE
     rb_define_const(c_storage_pool, "BUILD_NO_OVERWRITE",
                     INT2NUM(VIR_STORAGE_POOL_BUILD_NO_OVERWRITE));
-#endif
-
-#if HAVE_CONST_VIR_STORAGE_POOL_BUILD_OVERWRITE
     rb_define_const(c_storage_pool, "BUILD_OVERWRITE",
                     INT2NUM(VIR_STORAGE_POOL_BUILD_OVERWRITE));
-#endif
 
-#endif
-
-#if HAVE_TYPE_VIRSTORAGEVOLPTR
     /*
      * Class Libvirt::StorageVol and Libvirt::StorageVolInfo
      */
@@ -920,81 +865,49 @@ void ruby_libvirt_storage_init(void)
     c_storage_vol = rb_define_class_under(m_libvirt, "StorageVol",
                                           rb_cObject);
 
-#if HAVE_CONST_VIR_STORAGE_XML_INACTIVE
     rb_define_const(c_storage_vol, "XML_INACTIVE",
                     INT2NUM(VIR_STORAGE_XML_INACTIVE));
-#endif
 
     /* virStorageVolType */
     rb_define_const(c_storage_vol, "FILE", INT2NUM(VIR_STORAGE_VOL_FILE));
     rb_define_const(c_storage_vol, "BLOCK", INT2NUM(VIR_STORAGE_VOL_BLOCK));
-#if HAVE_CONST_VIR_STORAGE_VOL_DIR
     rb_define_const(c_storage_vol, "DIR", INT2NUM(VIR_STORAGE_VOL_DIR));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_NETWORK
     rb_define_const(c_storage_vol, "NETWORK", INT2NUM(VIR_STORAGE_VOL_NETWORK));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_NETDIR
     rb_define_const(c_storage_vol, "NETDIR", INT2NUM(VIR_STORAGE_VOL_NETDIR));
-#endif
 
     /* virStorageVolDeleteFlags */
     rb_define_const(c_storage_vol, "DELETE_NORMAL",
                     INT2NUM(VIR_STORAGE_VOL_DELETE_NORMAL));
     rb_define_const(c_storage_vol, "DELETE_ZEROED",
                     INT2NUM(VIR_STORAGE_VOL_DELETE_ZEROED));
-#if HAVE_CONST_VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS
     rb_define_const(c_storage_vol, "DELETE_WITH_SNAPSHOTS",
                     INT2NUM(VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS));
-#endif
 
     rb_define_method(c_storage_vol, "pool", libvirt_storage_vol_pool, 0);
     rb_define_method(c_storage_vol, "name", libvirt_storage_vol_name, 0);
     rb_define_method(c_storage_vol, "key", libvirt_storage_vol_key, 0);
     rb_define_method(c_storage_vol, "delete", libvirt_storage_vol_delete, -1);
-#if HAVE_VIRSTORAGEVOLWIPE
     rb_define_method(c_storage_vol, "wipe", libvirt_storage_vol_wipe, -1);
-#endif
-#if HAVE_VIRSTORAGEVOLWIPEPATTERN
     rb_define_method(c_storage_vol, "wipe_pattern",
                      libvirt_storage_vol_wipe_pattern, -1);
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_ZERO
     rb_define_const(c_storage_vol, "WIPE_ALG_ZERO",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_ZERO));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_NNSA
     rb_define_const(c_storage_vol, "WIPE_ALG_NNSA",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_NNSA));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_DOD
     rb_define_const(c_storage_vol, "WIPE_ALG_DOD",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_DOD));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_BSI
     rb_define_const(c_storage_vol, "WIPE_ALG_BSI",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_BSI));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_GUTMANN
     rb_define_const(c_storage_vol, "WIPE_ALG_GUTMANN",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_GUTMANN));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_SCHNEIER
     rb_define_const(c_storage_vol, "WIPE_ALG_SCHNEIER",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_SCHNEIER));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_PFITZNER7
     rb_define_const(c_storage_vol, "WIPE_ALG_PFITZNER7",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_PFITZNER7));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_PFITZNER33
     rb_define_const(c_storage_vol, "WIPE_ALG_PFITZNER33",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_PFITZNER33));
-#endif
-#if HAVE_CONST_VIR_STORAGE_VOL_WIPE_ALG_RANDOM
     rb_define_const(c_storage_vol, "WIPE_ALG_RANDOM",
                     INT2NUM(VIR_STORAGE_VOL_WIPE_ALG_RANDOM));
-#endif
 
     rb_define_method(c_storage_vol, "info", libvirt_storage_vol_info, 0);
     rb_define_method(c_storage_vol, "xml_desc", libvirt_storage_vol_xml_desc,
@@ -1002,13 +915,10 @@ void ruby_libvirt_storage_init(void)
     rb_define_method(c_storage_vol, "path", libvirt_storage_vol_path, 0);
     rb_define_method(c_storage_vol, "free", libvirt_storage_vol_free, 0);
 
-#if HAVE_VIRSTORAGEVOLDOWNLOAD
     rb_define_method(c_storage_vol, "download", libvirt_storage_vol_download,
                      -1);
     rb_define_method(c_storage_vol, "upload", libvirt_storage_vol_upload, -1);
-#endif
 
-#if HAVE_VIRSTORAGEVOLRESIZE
     rb_define_const(c_storage_vol, "RESIZE_ALLOCATE",
                     INT2NUM(VIR_STORAGE_VOL_RESIZE_ALLOCATE));
     rb_define_const(c_storage_vol, "RESIZE_DELTA",
@@ -1016,7 +926,4 @@ void ruby_libvirt_storage_init(void)
     rb_define_const(c_storage_vol, "RESIZE_SHRINK",
                     INT2NUM(VIR_STORAGE_VOL_RESIZE_SHRINK));
     rb_define_method(c_storage_vol, "resize", libvirt_storage_vol_resize, -1);
-#endif
-
-#endif
 }
